.. heizer documentation master file, created by
   sphinx-quickstart on Thu Dec 15 13:18:08 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to heizer's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: documentation

   tutorial/index
   heizer
